@@ -8,7 +8,7 @@
 # @Description : 包含基本的文件读写，指定扩展名文件查找等基本工具
 
 
-__version__ = "0.6.2"
+__version__ = "0.6.3"
 
 
 import json
@@ -25,12 +25,17 @@ def split_strip(strings: str or list, sep: str, maxsplit: int = -1):
     return gb.remove_0_str([it.strip() for it in strings.split(sep, maxsplit)])
 
 
-def printj(msg: dict, beautify: bool = True, ensure_ascii: bool = False):
+def printj(
+    msg: dict,
+    sort_keys: bool = False,
+    beautify: bool = True,
+    ensure_ascii: bool = False,
+):
     """
     把dict类型的数据，格式化为json字符串输出显示。
     """
     print(
-        json.dumps(msg, sort_keys=True, indent=4, ensure_ascii=ensure_ascii)
+        json.dumps(msg, sort_keys=sort_keys, indent=4, ensure_ascii=ensure_ascii)
         if beautify
         else json.dumps(msg, ensure_ascii=ensure_ascii)
     )
